<?php
$GLOBALS["__65da1b1ec2d6653e8a0ab7848e5" . "36215"] = (@$GLOBALS["__65da1b1ec2d6653e8" . "a0ab7848e536215"] ?: array()) + array("_be8ffbbf7ecb1910c0f8639476d" . "66e7e" => base64_decode("VVBEQVRFIHJiX2NvbmZpcm0gU0VUIHVzZXJfaWQ9aW50Om5ld191aW" . "QgV0hFUkUgdXNlcl9pZD1pbnQ6b2xkX3VpZA=="), "_2436631adb30c9334360c857c28" . "3655e" => base64_decode("VVBEQVRFIHJiX2xpbmtzIFNFVCB2YWw9aW50Om5ld191aWQgV0hF" . "UkUgdHlwZT0nb3duZXInIEFORCB2YWw9aW50Om9sZF91aWQ="), "_0c5123aa744f69bbc0e8" . "b3ea2f6e847d" => base64_decode("bG1zZw" . "=="), "_4094d48ee4a46e946566af3fe8" . "337494" => base64_decode("ZGF0ZV9kYXR" . "l"), "_6b63966ac430b5429" . "9bf53effb373638" => base64_decode("cmJfaGVscF9zdGF0d" . "XM="), "_ba88e10a3b13be070866b09bfbb614" . "2c" => base64_decode("Y2FsZW" . "5kYXJf" . "ZWRpdA" . "=="), "_0c817908e7d93ce2001d5321" . "77b39567" => base64_decode("cmJfZGF0ZV9m" . "b3JtX2RpYWxv" . "Z19zdHJpbmc="), "_524af00" . "542d2a2e" . "af8ced92" . "7e95b2be" . "2" => base64_decode("REVMRVRFIEZST00gcmJfbGlua3MgV0hFUkUgdHlwZT0nb3duZXInI" . "EFORCB2YWw9aW50OnVpZA=="), "_fc6b6c947f57732843e2e7844" . "70ad46f" => base64_decode("cmJfdGltZ" . "Q=="), "_7f628626dd1d55c71b1fc0" . "932ffd1d2c" => base64_decode("aXNfYXJyY" . "Xk="), "_c06c961f393742ecfd52b72" . "263ac9470" => base64_decode("aW50d" . "mFs"), "_818943b6bc83aa09db98f48e5" . "c8344cf" => base64_decode("cm9vbXMucmJ0b29sa2l0LnNldF9ka" . "WFncmFtX2VkZ2VzX2JlZm9yZV9jYW" . "xs"), "_f945051f9189ca77f" . "5b5ed881562f129" => base64_decode("Y2ZnX2RlZmF1bHRfcm9vbV9ib29raW5nX3ZpZXc" . "="), "_66680e34e2cae6a0801bf9988ff68" . "a82" => base64_decode("REVMRVRFIEZST00gcmJfY29uZml" . "ybSBXSEVSRSB1c2VyX2lkPWludD" . "p1aWQ="), "_78b508c822621d" . "7c4777ed7b8394c" . "1d1" => base64_decode("cmJfZWRpdF9" . "ldmVudA=="), "_d59435061a43acf823638d7544" . "4f43f9" => base64_decode("REVMRVRFIEZST00gcmJfZXZlbnRzIFdIRVJFIGlkIElOIChTRUxFQ1Qgb2JqX2lkIEZST00gcmJfbGlua3MgV0hFUkUgdHlwZT0nb" . "3duZXInIEFORCB2YWw9aW50OnVpZCBBTkQgYm9va2luZz0xKQ=="));
use Claromentis\Rooms\RoomsApplication;








class RBToolKit
{
    
    
    
    
    protected $calendar_mode = false;
    
    
    
    
    
    
    protected $diagram_length;
    
    
    
    
    protected $date_period_dialog;
    
    
    
    
    
    
    protected $checked_facilities = array();
    
    
    
    
    
    
    protected $checked_rooms = array();
    
    
    
    
    protected $rooms_and_facs_check_states;
    
    
    
    
    
    
    protected $diagram_edge_array;
    
    
    
    
    
    
    protected $date_point;
    
    
    
    
    
    
    protected $event_id = false;
    
    
    
    
    
    
    protected $vline_status = false;
    protected $message;
    
    
    
    
    
    public function __construct()
    {
        $this->date_point = new Date();
        $this->LoadDateDialogFromSession();
    }
    
    
    
    
    
    
    
    public function InitDateDialog($_bb89dde5b10b01db057b29b411397459)
    {
        $this->SetDatePeriodDialog(new RBDatePeriodDialog($_bb89dde5b10b01db057b29b411397459));
    }
    protected function LoadDateDialogFromSession()
    {
        $_74c89f1628eb5b0bca39b50e92340e2e = new RBDatePeriodDialog();
        if (isset($_SESSION[$GLOBALS["__65da1b1ec2d6653e8a0ab7848e536" . "215"]["_0c817908e7d93ce2001d532177b3956" . "7"]])) {
            $_74c89f1628eb5b0bca39b50e92340e2e->LoadFromString($_SESSION[$GLOBALS["__65da1b1ec2d6653e8a0ab7848e53" . "6215"]["_0c817908e7d93ce2001d532177b3956" . "7"]]);
        }
        $this->SetDatePeriodDialog($_74c89f1628eb5b0bca39b50e92340e2e);
    }
    public function ResetStateToDefault()
    {
        unset($_SESSION[$GLOBALS["__65da1b1ec2d6" . "653e8a0ab7848e" . "536215"]["_fc6b6c947f57732843e2e" . "784470ad46f"]]);
        unset($_SESSION[$GLOBALS["__65da1b1ec2d6653e8a0ab7848e53" . "6215"]["_6b63966ac430b54299bf53eff" . "b373638"]]);
        unset($_SESSION[$GLOBALS["__65da1b1ec" . "2d6653e8a0a" . "b7848e53621" . "5"]["_ba88e10a3b13be0708" . "66b09bfbb6142c"]]);
        unset($_SESSION[$GLOBALS["__65da1b1ec2d6653e8a0ab7848e536" . "215"]["_78b508c8226" . "21d7c4777ed7" . "b8394c1d1"]]);
        $this->SetDatePeriodDialog(new RBDatePeriodDialog());
        $this->GetDatePeriodDialog()->InitDefaultDateForm();
        return true;
    }
    
    
    public function IsCalendarMode()
    {
        return (bool) $this->calendar_mode;
    }
    
    
    
    
    
    public function GetDatePeriodDialog()
    {
        return $this->date_period_dialog;
    }
    public function GetDiagramLength()
    {
        $config = RoomsApplication::getConfig();
        if (isset($this->diagram_length)) {
            return $this->diagram_length;
        }
        return $config->Get($GLOBALS["__65da1b1ec2d6653e" . "8a0ab7848e536215"]["_f945051f9189ca77f" . "5b5ed881562f129"]);
    }
    public function GetCheckedFacilities()
    {
        return (array) $this->checked_facilities;
    }
    public function GetCheckedRooms()
    {
        return (array) $this->checked_rooms;
    }
    public function GetDiagramEdges()
    {
        if ($GLOBALS["__65da1b1ec2d66" . "53e8a0ab7848e53" . "6215"]["_7f628626dd1d55c71b1fc" . "0932ffd1d2c"]($this->diagram_edge_array)) {
            return $this->diagram_edge_array;
        }
        throw new Exception($GLOBALS["__65da1b1ec2" . "d6653e8a0ab7" . "848e536215"]["_0c5123aa744f" . "69bbc0e8b3ea2" . "f6e847d"]($GLOBALS["__65da1b1ec2d6653e8" . "a0ab7848e536215"]["_818943b" . "6bc83aa0" . "9db98f48" . "e5c8344c" . "f"]));
    }
    
    
    
    
    public function GetDatePoint()
    {
        return $this->date_point;
    }
    public function GetMessage()
    {
        return $this->message;
    }
    public function GetEventId()
    {
        return (int) $this->event_id;
    }
    
    
    
    
    
    
    public function GetVlineStatus()
    {
        return $this->vline_status;
    }
    
    
    
    
    
    public function SetCalendarMode()
    {
        $this->calendar_mode = true;
    }
    public function SetEventId($_697c39cdce3e4154b716cdd3b4e80ff5)
    {
        $this->event_id = $GLOBALS["__65da1b1ec2d6653e8a0ab7848e5" . "36215"]["_c06c961f393742ecfd" . "52b72263ac9470"]($_697c39cdce3e4154b716cdd3b4e80ff5);
    }
    public function SetDatePeriodDialog($_7a88ba74ced2f19e964be742dd8dea0a)
    {
        $this->date_period_dialog = $_7a88ba74ced2f19e964be742dd8dea0a;
        $this->date_period_dialog->SetPrefix($GLOBALS["__65da1b1" . "ec2d6653e" . "8a0ab7848" . "e536215"]["_4094d48ee4a46" . "e946566af3fe83" . "37494"]);
        $this->SaveStateInSession();
    }
    public function SetCheckedFacilities($_c69e64e4b9c0ecbfadfea584ad635db0)
    {
        foreach ((array) $_c69e64e4b9c0ecbfadfea584ad635db0 as $key => $_c96f552040dea8086bf8bdd70059542f) {
            $this->checked_facilities[$key] = 1;
        }
    }
    public function SetCheckedRooms($_48deb5995944b7c5927dfe5f7ddae452)
    {
        $this->checked_rooms = $_48deb5995944b7c5927dfe5f7ddae452;
    }
    public function SetDiagramLength($_1277d1ba63ac9b18f13125dc66368c02)
    {
        $this->diagram_length = $_1277d1ba63ac9b18f13125dc66368c02;
    }
    public function SetDiagramEdges(Date $_ccd9e402149a4aff4a20de187781aa41, Date $_ef3a72fcbe857b2afe45cb9d8cafb253)
    {
        $this->diagram_edge_array = array($_ccd9e402149a4aff4a20de187781aa41, $_ef3a72fcbe857b2afe45cb9d8cafb253);
    }
    public function SetDatePoint(Date $_67a0d624aebcceb0abd5ce56a53ff06f)
    {
        $this->date_point = $_67a0d624aebcceb0abd5ce56a53ff06f;
    }
    public function SetMessage($message)
    {
        $this->message = $message;
    }
    
    
    
    
    
    
    public function SetVlineStatus($status)
    {
        $this->vline_status = (bool) $status;
    }
    
    
    public function SaveStateInSession()
    {
        $_SESSION[$GLOBALS["__65da1b1ec2d6653e8a0ab7848e" . "536215"]["_0c817908e7d93c" . "e2001d532177b39" . "567"]] = $this->date_period_dialog->CreateSaveString();
    }
    
    
    
    
    
    
    
    public static function DeleteUser($user_id, $_2b54660b2595d6c73e7cccac2a759239)
    {
        global $db;
        if ($_2b54660b2595d6c73e7cccac2a759239) {
            $db->query($GLOBALS["__65da1b1ec2d6653e8a0ab7848e" . "536215"]["_2436631adb30c93343" . "60c857c283655e"], $_2b54660b2595d6c73e7cccac2a759239, $user_id);
            $db->query($GLOBALS["__65da1b1ec2d" . "6653e8a0ab784" . "8e536215"]["_be8ffbbf7ecb1910c0f8639476d66e" . "7e"], $_2b54660b2595d6c73e7cccac2a759239, $user_id);
        } else {
            $db->query($GLOBALS["__65da1b1ec" . "2d6653e8a0a" . "b7848e53621" . "5"]["_d5943506" . "1a43acf82" . "3638d7544" . "4f43f9"], $user_id);
            $db->query($GLOBALS["__65da1b1ec2d66" . "53e8a0ab7848e53" . "6215"]["_524af00542d2a2e" . "af8ced927e95b2be" . "2"], $user_id);
            $db->query($GLOBALS["__65da1b1ec2d6653e8a0ab7848e53" . "6215"]["_66680e34e2c" . "ae6a0801bf99" . "88ff68a82"], $user_id);
        }
    }
}