<?php
$GLOBALS["__65da1b1ec2d6653e8a0" . "ab7848e536215"] = (@$GLOBALS["__65da1b1ec2" . "d6653e8a0ab7" . "848e536215"] ?: array()) + array("_25867e3e3db" . "28969253f3a3" . "70c3166ba" => base64_decode("ZGVzYw=" . "="), "_66aaa4202afc087cc" . "c629429b94f26cf" => base64_decode("bmV4dA" . "=="), "_04014b4c4cd7f" . "8beafc06c91213" . "9b979" => base64_decode("aHR0cFJlZG" . "lyZWN0"), "_59be04fc0edf7" . "507f42c6c80666" . "dc1e3" => base64_decode("UEhQX1" . "NFTEY="), "_78b508c822621d7c4777ed7b8394c" . "1d1" => base64_decode("cmJfZWRpdF9ldmVudA=" . "="), "_62c6c04046599d" . "440b89fcd177155" . "a32" => base64_decode("cm9vbXMucmJhY3Rpb24uZXZlb" . "nRfbm90X2ZvdW5k"), "_0c5123a" . "a744f69b" . "bc0e8b3e" . "a2f6e847" . "d" => base64_decode("bG1zZw=" . "="), "_2ec9a485dd285c28c8e85f01" . "a8945982" => base64_decode("cm9vbXMu" . "dG9vbGtp" . "dA=="), "_511be8cd8d8" . "bae4efce6b6d" . "d4ff70530" => base64_decode("ZWRpdF9ldmVudA=" . "="), "_4dbcdc0af6ad69a200eb60c" . "81e26305c" => base64_decode("M" . "D" . "A" . "="), "_e21aea73c33e96e" . "f626d3b3bf962359" . "3" => base64_decode("YXJyYXlfc" . "HVzaA=="), "edit_i" . "d" => base64_decode("ZWRpdF9" . "pZA=="), "_7277920cd79b72818ba498a7b06d9f7" . "3" => base64_decode("cm9vbXMucmJhY3Rpb24uYm9va2" . "luZ193YXNfZGVs"), "i" . "d" => base64_decode("aWQ" . "="), "_5b81cb6cf0b" . "fd990583fc12" . "ddd80cd32" => base64_decode("Z" . "m" . "F" . "j"), "_2acee844826294" . "51244aab96a0162" . "3cd" => base64_decode("cm" . "9v" . "bQ" . "=="), "na" . "me" => base64_decode("bmF" . "tZQ" . "=="), "_bf597f0023" . "796d52ab864" . "e5096729090" => base64_decode("cHJldg=" . "="), "_9ec0673d3f363160cec842dd8" . "4da335d" => base64_decode("ZGVsZXRlX2V2Z" . "W50"), "_d706c160e45bf7434fff82a" . "5976f0e19" => base64_decode("YXJyYXlfa2V5cw" . "=="), "_be2f530b7f7942" . "3353d454b8acd8e" . "cb4" => base64_decode("bG9uZw" . "=="));
use Claromentis\Rooms\Exception\EventNotFoundException;






class RBActionsProcessor extends ErrorHandler
{
    const DIAGRAM_PERIOD_WEEK = 0;
    const DIAGRAM_PERIOD_BIWEEK = 1;
    const DIAGRAM_PERIOD_DAY = 2;
    protected $redir = false;
    protected $message;
    protected $is_error = false;
    protected $allow_redirect = true;
    
    
    
    
    protected $toolkit;
    public function __construct($_8360eb382bc61a4bb036cc1aa0860698 = true)
    {
        global $g_application;
        $this->allow_redirect = $_8360eb382bc61a4bb036cc1aa0860698;
        $this->toolkit = $g_application[$GLOBALS["__65da1b1" . "ec2d6653e" . "8a0ab7848" . "e536215"]["_2ec9a485dd285c28c8e85f01a89" . "45982"]];
        
        
    }
    
    
    
    
    
    
    public function ProcessAction($action)
    {
        switch ($action) {
            case $GLOBALS["__65da1b1ec2d6653e8a0ab7848e" . "536215"]["_9ec0673d3f3631" . "60cec842dd84da3" . "35d"]:
                gpc::CheckToken();
                $this->_delEvent();
                break;
            case $GLOBALS["__65da1b1ec2d6653e" . "8a0ab7848e536215"]["_511be8cd" . "8d8bae4ef" . "ce6b6dd4f" . "f70530"]:
                $this->_editEvent();
                break;
            case $GLOBALS["__65da1b1ec2d6653e8a0" . "ab7848e536215"]["_66aaa4202afc" . "087ccc629429b" . "94f26cf"]:
                $this->_processNextScreen();
                break;
            case $GLOBALS["__65da1b1ec2d665" . "3e8a0ab7848e5362" . "15"]["_bf597f0023796d52ab864e5" . "096729090"]:
                $this->_processPrevScreen();
                break;
        }
        $this->_setGraphInterval();
        $this->toolkit->SaveStateInSession();
        if ($this->redir) {
            $this->_redirPage();
        }
    }
    
    
    
    
    protected function _editEvent()
    {
        $_68ffaaa31e3ba49ed9d6159fbee9f043 = new RBBooking(new RBFacade());
        $_68ffaaa31e3ba49ed9d6159fbee9f043->Load($this->toolkit->GetEventId());
        $_343a395319323dd7609bcbc465b4d034 = $_68ffaaa31e3ba49ed9d6159fbee9f043->_getChildList();
        $GLOBALS["__65da1b1ec2d6653e8a0" . "ab7848e536215"]["_e21aea73c33e96ef" . "626d3b3bf9623593"]($_343a395319323dd7609bcbc465b4d034, $_68ffaaa31e3ba49ed9d6159fbee9f043->id);
        $_SESSION[$GLOBALS["__65da1b1ec2d6653e8a0ab7848e5" . "36215"]["_78b508c822621d7c4777ed7b8394c1d" . "1"]] = array($GLOBALS["__65da1b1e" . "c2d6653e8a" . "0ab7848e53" . "6215"]["i" . "d"] => $_343a395319323dd7609bcbc465b4d034, $GLOBALS["__65da1b1ec2d6653e8a0ab7848e5" . "36215"]["edit_" . "id"] => $_68ffaaa31e3ba49ed9d6159fbee9f043->id, $GLOBALS["__65da1b1ec2d6653e" . "8a0ab7848e536215"]["nam" . "e"] => $_68ffaaa31e3ba49ed9d6159fbee9f043->name, $GLOBALS["__65da1b1ec2d6653e8a0ab7848" . "e536215"]["_25867e3" . "e3db2896" . "9253f3a3" . "70c3166b" . "a"] => $_68ffaaa31e3ba49ed9d6159fbee9f043->desc, $GLOBALS["__65da1b1ec2d6653e8a0ab7848e53621" . "5"]["_2acee8448" . "2629451244" . "aab96a0162" . "3cd"] => $GLOBALS["__65da1b1" . "ec2d6653e" . "8a0ab7848" . "e536215"]["_d706c160e45bf7434fff8" . "2a5976f0e19"]($_68ffaaa31e3ba49ed9d6159fbee9f043->GetObjList($GLOBALS["__65da1b1ec2d6653e" . "8a0ab7848e536215"]["_2acee84482629451" . "244aab96a01623cd"])));
        $_343a395319323dd7609bcbc465b4d034 = $this->_createFacArray($_68ffaaa31e3ba49ed9d6159fbee9f043);
        $this->_initFormFromEditingEvent($_68ffaaa31e3ba49ed9d6159fbee9f043);
    }
    
    
    
    
    
    
    
    public function UpdateEvent($_697c39cdce3e4154b716cdd3b4e80ff5, $_5693d84b45564f912e36404cbe8957e8, $_4d031b4f6f4558056f5ba8c4e193225a, $_68850b1507f146443ff5d1f5a5460e75)
    {
        $_68ffaaa31e3ba49ed9d6159fbee9f043 = new RBBooking(new RBFacade());
        $_68ffaaa31e3ba49ed9d6159fbee9f043->Load($_697c39cdce3e4154b716cdd3b4e80ff5);
        $this->_changeEvent($_68ffaaa31e3ba49ed9d6159fbee9f043, $_5693d84b45564f912e36404cbe8957e8, $_4d031b4f6f4558056f5ba8c4e193225a, $_68850b1507f146443ff5d1f5a5460e75);
        $_dcd18f1ae5fbc1bd429492db158908aa = new RBFacade();
        $_c8b38c7133c2e8460c1cca42230ac6c2 = $_dcd18f1ae5fbc1bd429492db158908aa->DeleteEvent($_68ffaaa31e3ba49ed9d6159fbee9f043->id);
    }
    
    
    
    
    
    
    
    
    
    protected function _changeEvent($_68ffaaa31e3ba49ed9d6159fbee9f043, $_5693d84b45564f912e36404cbe8957e8, $_4d031b4f6f4558056f5ba8c4e193225a, $_68850b1507f146443ff5d1f5a5460e75)
    {
        $_dcd18f1ae5fbc1bd429492db158908aa = new RBFacade();
        $_dcd18f1ae5fbc1bd429492db158908aa->ChangeEvent($this->toolkit->GetDatePeriodDialog(), $_5693d84b45564f912e36404cbe8957e8, $_4d031b4f6f4558056f5ba8c4e193225a, $_68850b1507f146443ff5d1f5a5460e75, $this->toolkit->GetCheckedFacilities(), AuthUser::I()->GetId(), $_68ffaaa31e3ba49ed9d6159fbee9f043);
        $this->_initDateForm(new Date($this->toolkit->GetDatePeriodDialog()->GetHeadDatePeriod()->start[$GLOBALS["__65da1b1ec2d6653e8a0ab784" . "8e536215"]["_be2f530b7" . "f79423353d" . "454b8acd8e" . "cb4"]] . $GLOBALS["__65da1b1ec2d6653e8a0ab7848e536" . "215"]["_4dbcdc0af6" . "ad69a200eb6" . "0c81e26305c"]));
        
        
    }
    
    
    
    
    
    protected function _createFacArray($_68ffaaa31e3ba49ed9d6159fbee9f043)
    {
        $_343a395319323dd7609bcbc465b4d034 = $_68ffaaa31e3ba49ed9d6159fbee9f043->GetObjList($GLOBALS["__65da1b1ec2d6653e8a0ab7848e536" . "215"]["_5b81cb6cf0bfd990583fc12ddd8" . "0cd32"]);
        $_094e18a2dde09a1246a956dacefdbc9c = array();
        foreach ((array) $_343a395319323dd7609bcbc465b4d034 as $key => $_c96f552040dea8086bf8bdd70059542f) {
            $_5b81cb6cf0bfd990583fc12ddd80cd32 = new RBFac(new RBFacade());
            $_5b81cb6cf0bfd990583fc12ddd80cd32->Load($key);
            $_094e18a2dde09a1246a956dacefdbc9c[$_5b81cb6cf0bfd990583fc12ddd80cd32->pid][$key] = 1;
        }
        return $_094e18a2dde09a1246a956dacefdbc9c;
    }
    
    
    
    
    protected function _initFormFromEditingEvent($_68ffaaa31e3ba49ed9d6159fbee9f043)
    {
        $_a335e14ddefbedf8ca192d19ab93691e = new RBDatePeriodDialog();
        $_a335e14ddefbedf8ca192d19ab93691e->CreateFromEvent($_68ffaaa31e3ba49ed9d6159fbee9f043);
        $this->toolkit->SetDatePeriodDialog($_a335e14ddefbedf8ca192d19ab93691e);
    }
    
    
    
    
    
    
    
    
    
    public function AddEvent($_68850b1507f146443ff5d1f5a5460e75, $_5693d84b45564f912e36404cbe8957e8, $_df4ae3ddb85ca6bd03e27e1d86fa3c41)
    {
        $_dcd18f1ae5fbc1bd429492db158908aa = new RBFacade();
        $_18cb991d3787967aac03336ac7811b3d = $_dcd18f1ae5fbc1bd429492db158908aa->CreateEvent($this->toolkit->GetDatePeriodDialog(), $_5693d84b45564f912e36404cbe8957e8, $_df4ae3ddb85ca6bd03e27e1d86fa3c41, $_68850b1507f146443ff5d1f5a5460e75, $this->toolkit->GetCheckedFacilities(), AuthUser::I()->GetId());
        $this->_initDateForm(new Date($this->toolkit->GetDatePeriodDialog()->GetHeadDatePeriod()->start[$GLOBALS["__65da1b1ec2d66" . "53e8a0ab7848e53" . "6215"]["_be2f530b7f79423353d4" . "54b8acd8ecb4"]] . $GLOBALS["__65da1b1ec2d665" . "3e8a0ab7848e5362" . "15"]["_4dbcdc0af6ad69a200eb60c81" . "e26305c"]));
        return $_18cb991d3787967aac03336ac7811b3d;
    }
    
    
    
    
    protected function _initDateForm($_91d10773c15d92f509551b22650c8a4e)
    {
        $this->toolkit->SetDatePoint($_91d10773c15d92f509551b22650c8a4e);
        $this->toolkit->GetDatePeriodDialog()->InitDefaultDateForm($_91d10773c15d92f509551b22650c8a4e);
    }
    
    
    
    
    protected function _delEvent($_81c1fba056fca0b94d585482be6fe046 = false)
    {
        if (!$_81c1fba056fca0b94d585482be6fe046) {
            $_81c1fba056fca0b94d585482be6fe046 = $this->toolkit->GetEventId();
        }
        $_dcd18f1ae5fbc1bd429492db158908aa = new RBFacade();
        try {
            $_c8b38c7133c2e8460c1cca42230ac6c2 = $_dcd18f1ae5fbc1bd429492db158908aa->DeleteEvent($_81c1fba056fca0b94d585482be6fe046);
            $this->_initDateForm(new Date($_c8b38c7133c2e8460c1cca42230ac6c2 . $GLOBALS["__65da1b1ec2d6653e8a0" . "ab7848e536215"]["_4dbcdc0af6ad69a200eb60c81e" . "26305c"]));
            $this->message = $GLOBALS["__65da1b1ec" . "2d6653e8a0a" . "b7848e53621" . "5"]["_0c5123aa744f69bbc0e8b3" . "ea2f6e847d"]($GLOBALS["__65da1b1ec2" . "d6653e8a0ab7" . "848e536215"]["_7277920cd79b72818ba4" . "98a7b06d9f73"]);
        } catch (EventNotFoundException $e) {
            $this->is_error = true;
            $this->message = $GLOBALS["__65da1b1ec2d" . "6653e8a0ab784" . "8e536215"]["_0c5123aa744f69bbc0e8b3ea" . "2f6e847d"]($GLOBALS["__65da1b1ec2d6653e8a0ab7848" . "e536215"]["_62c6c040465" . "99d440b89fcd" . "177155a32"]);
        }
        $this->redir = true;
    }
    
    
    
    
    protected function _redirPage()
    {
        if ($this->allow_redirect) {
            $GLOBALS["__65da1b1ec2d" . "6653e8a0ab784" . "8e536215"]["_04014b4c4cd7f8beafc06c912" . "139b979"]($_SERVER[$GLOBALS["__65da1b1ec2" . "d6653e8a0ab7" . "848e536215"]["_59be04fc0edf7507f" . "42c6c80666dc1e3"]], $this->message, $this->is_error);
            exit;
        }
    }
    
    
    
    
    protected function _processNextScreen()
    {
        $_67a0d624aebcceb0abd5ce56a53ff06f = $this->toolkit->GetDatePoint();
        switch ($this->toolkit->GetDiagramLength()) {
            case self::DIAGRAM_PERIOD_WEEK:
                $this->toolkit->SetDatePoint($_67a0d624aebcceb0abd5ce56a53ff06f->getBeginOfNextWeek());
                break;
            case self::DIAGRAM_PERIOD_BIWEEK:
                $this->toolkit->SetDatePoint($_67a0d624aebcceb0abd5ce56a53ff06f->getBeginOfNextWeek()->getBeginOfNextWeek());
                break;
            case self::DIAGRAM_PERIOD_DAY:
                $this->toolkit->SetDatePoint($_67a0d624aebcceb0abd5ce56a53ff06f->getNextDay());
                break;
        }
    }
    
    
    
    
    protected function _processPrevScreen()
    {
        $_67a0d624aebcceb0abd5ce56a53ff06f = $this->toolkit->GetDatePoint();
        switch ($this->toolkit->GetDiagramLength()) {
            case self::DIAGRAM_PERIOD_WEEK:
                $this->toolkit->SetDatePoint($_67a0d624aebcceb0abd5ce56a53ff06f->getBeginOfPrevWeek());
                break;
            case self::DIAGRAM_PERIOD_BIWEEK:
                $this->toolkit->SetDatePoint($_67a0d624aebcceb0abd5ce56a53ff06f->getBeginOfPrevWeek()->getBeginOfPrevWeek());
                break;
            case self::DIAGRAM_PERIOD_DAY:
                $this->toolkit->SetDatePoint($_67a0d624aebcceb0abd5ce56a53ff06f->getPrevDay());
                break;
        }
    }
    
    
    
    
    protected function _setGraphInterval()
    {
        $_67a0d624aebcceb0abd5ce56a53ff06f = $this->toolkit->GetDatePoint();
        switch ($this->toolkit->GetDiagramLength()) {
            case self::DIAGRAM_PERIOD_BIWEEK:
                $this->toolkit->SetDiagramEdges($_67a0d624aebcceb0abd5ce56a53ff06f->getBeginOfWeek(), $_67a0d624aebcceb0abd5ce56a53ff06f->getBeginOfNextWeek()->getEndOfWeek());
                break;
            case self::DIAGRAM_PERIOD_DAY:
                $this->toolkit->SetDiagramEdges($_67a0d624aebcceb0abd5ce56a53ff06f, $_67a0d624aebcceb0abd5ce56a53ff06f);
                break;
            default:
                $this->toolkit->SetDiagramEdges($_67a0d624aebcceb0abd5ce56a53ff06f->getBeginOfWeek(), $_67a0d624aebcceb0abd5ce56a53ff06f->getEndOfWeek());
                break;
        }
    }
}